@@ -2,7 +2,7 @@ import glfw
 import imgui
 from scNodes.core import settings
 from scNodes.core import config as cfg
-from scNodes.core.dataset import *
+from scNodes.core.datatypes import *
 from scNodes.core.roi import *
 from tkinter import filedialog
 from scNodes.core.util import save_tiff
@@ -47,8 +47,8 @@ class ImageViewer:
         self.imgui_implementation = imgui_implementation
 
         # Rendering related objects and vars
-        self.shader = Shader(cfg.root+"shaders/textured_shader.glsl")
-        self.roi_shader = Shader(cfg.root+"shaders/line_shader.glsl")
+        self.shader = Shader(cfg.root+"shaders/iv_textured_shader.glsl")
+        self.roi_shader = Shader(cfg.root+"shaders/iv_line_shader.glsl")
         self.texture = Texture(format="rgb32f")
         self.fbo = FrameBuffer(*settings.def_img_size)
         self.va = VertexArray()
@@ -186,7 +186,6 @@ class ImageViewer:
             ImageViewer.MARKER_COLOUR = cfg.active_node.colour
             self.node_blocking_frame_window = cfg.active_node.DISABLE_FRAME_INFO_WINDOW
             if self.previous_active_node is not cfg.active_node or cfg.active_node.any_change or self.new_image_requested:
-                print("IV getting new image")
                 if cfg.active_node.NODE_RETURNS_IMAGE:
                     an = cfg.active_node
                     self.current_dataset = an.get_source_load_data_node(an).dataset
@@ -320,7 +319,6 @@ class ImageViewer:
             self.marker.render_end(self.roi_shader)
 
     def _frame_info_window(self):
-
         imgui.push_style_var(imgui.STYLE_WINDOW_ROUNDING, 0.0)
         imgui.set_next_window_position(0, self.window.height - ImageViewer.INFO_BAR_HEIGHT + (cfg.window_height - self.window.height), imgui.ALWAYS)
         imgui.set_next_window_size(self.window.width, ImageViewer.INFO_BAR_HEIGHT)
@@ -534,7 +532,7 @@ class ImageViewer:
                                  width, height, 1.0, 1.0, 1.0]
             indices = [0, 1, 2, 2, 0, 3]
             self.va.update(VertexBuffer(vertex_attributes), IndexBuffer(indices))
-        self.texture.update(self.image_pxd.astype(np.float))
+        self.texture.update(self.image_pxd.astype(float))
 
         self.hist_counts[0], self.hist_bins[0] = np.histogram(self.image_pxd[:, :, 0], bins=ImageViewer.HISTOGRAM_BINS)
         self.hist_counts[0] = self.hist_counts[0].astype('float32')
